@@ -8,9 +8,8 @@ from django.http import HttpResponseRedirect
 from django.shortcuts import redirect
 from django.urls import reverse
 
-from db.base.models import Artifact, DemodData, ExportedFrameset, \
-    LatestTleSet, Mode, Operator, Satellite, Telemetry, Tle, Transmitter, \
-    TransmitterEntry, TransmitterSuggestion
+from db.base.models import Artifact, DemodData, ExportedFrameset, LatestTleSet, Mode, Operator, \
+    Satellite, Telemetry, Tle, Transmitter, TransmitterEntry, TransmitterSuggestion
 from db.base.tasks import check_celery, decode_all_data, update_tle_sets
 from db.base.utils import update_latest_tle_sets
 
@@ -254,16 +253,16 @@ class TleAdmin(admin.ModelAdmin):
 
     def save_model(self, request, obj, form, change):
         super().save_model(request, obj, form, change)
-        update_latest_tle_sets(satellites=[obj.satellite.pk])
+        update_latest_tle_sets(satellite_ids=[obj.satellite.pk])
 
     def delete_model(self, request, obj):
         super().delete_model(request, obj)
-        update_latest_tle_sets(satellites=[obj.satellite.pk])
+        update_latest_tle_sets(satellite_ids=[obj.satellite.pk])
 
     def delete_queryset(self, request, queryset):
         satellites = [tle.satellite.pk for tle in queryset]
         super().delete_queryset(request, queryset)
-        update_latest_tle_sets(satellites=satellites)
+        update_latest_tle_sets(satellite_ids=satellites)
 
 
 @admin.register(LatestTleSet)
